@@ -29,6 +29,9 @@ from litellm.llms.anthropic.cost_calculation import (
 from litellm.llms.azure.cost_calculation import (
     cost_per_token as azure_openai_cost_per_token,
 )
+from litellm.llms.bedrock.cost_calculation import (
+    cost_per_token as bedrock_cost_per_token,
+)
 from litellm.llms.bedrock.image.cost_calculator import (
     cost_calculator as bedrock_image_cost_calculator,
 )
@@ -326,6 +329,8 @@ def cost_per_token(  # noqa: PLR0915
             )
     elif custom_llm_provider == "anthropic":
         return anthropic_cost_per_token(model=model, usage=usage_block)
+    elif custom_llm_provider == "bedrock":
+        return bedrock_cost_per_token(model=model, usage=usage_block)
     elif custom_llm_provider == "openai":
         return openai_cost_per_token(model=model, usage=usage_block)
     elif custom_llm_provider == "databricks":
@@ -780,6 +785,22 @@ def completion_cost(  # noqa: PLR0915
                         raise TypeError(
                             "completion_response must be of type ImageResponse for bedrock image cost calculation"
                         )
+                    elif custom_llm_provider == litellm.LlmProviders.RECRAFT.value:
+                        from litellm.llms.recraft.cost_calculator import (
+                            cost_calculator as recraft_image_cost_calculator,
+                        )
+                        return recraft_image_cost_calculator(
+                            model=model,
+                            image_response=completion_response,
+                        )
+                    elif custom_llm_provider == litellm.LlmProviders.GEMINI.value:
+                        from litellm.llms.gemini.image_generation.cost_calculator import (
+                            cost_calculator as gemini_image_cost_calculator,
+                        )
+                        return gemini_image_cost_calculator(
+                            model=model,
+                            image_response=completion_response,
+                        )
                     else:
                         return default_image_cost_calculator(
                             model=model,
