@@ -1,16 +1,24 @@
 from datetime import datetime
-from typing import Dict, List, Literal, Optional, Type, Union
+from typing import Any, Dict, List, Literal, Optional, Type, Union, get_args
 
 from litellm._logging import verbose_logger
+from litellm.caching import DualCache
 from litellm.integrations.custom_logger import CustomLogger
 from litellm.types.guardrails import (
     DynamicGuardrailParams,
     GuardrailEventHooks,
     LitellmParams,
+    Mode,
     PiiEntityType,
 )
 from litellm.types.proxy.guardrails.guardrail_hooks.base import GuardrailConfigModel
-from litellm.types.utils import StandardLoggingGuardrailInformation
+from litellm.types.utils import (
+    CallTypes,
+    LLMResponseTypes,
+    StandardLoggingGuardrailInformation,
+)
+
+dc = DualCache()
 
 
 class CustomGuardrail(CustomLogger):
@@ -19,7 +27,7 @@ class CustomGuardrail(CustomLogger):
         guardrail_name: Optional[str] = None,
         supported_event_hooks: Optional[List[GuardrailEventHooks]] = None,
         event_hook: Optional[
-            Union[GuardrailEventHooks, List[GuardrailEventHooks]]
+            Union[GuardrailEventHooks, List[GuardrailEventHooks], Mode]
         ] = None,
         default_on: bool = False,
         mask_request_content: bool = False,
@@ -40,7 +48,7 @@ class CustomGuardrail(CustomLogger):
         self.guardrail_name = guardrail_name
         self.supported_event_hooks = supported_event_hooks
         self.event_hook: Optional[
-            Union[GuardrailEventHooks, List[GuardrailEventHooks]]
+            Union[GuardrailEventHooks, List[GuardrailEventHooks], Mode]
         ] = event_hook
         self.default_on: bool = default_on
         self.mask_request_content: bool = mask_request_content
@@ -63,15 +71,16 @@ class CustomGuardrail(CustomLogger):
 
     def _validate_event_hook(
         self,
-        event_hook: Optional[Union[GuardrailEventHooks, List[GuardrailEventHooks]]],
+        event_hook: Optional[
+            Union[GuardrailEventHooks, List[GuardrailEventHooks], Mode]
+        ],
         supported_event_hooks: List[GuardrailEventHooks],
     ) -> None:
 
-        if event_hook is None:
-            return
-        if isinstance(event_hook, str):
-            event_hook = GuardrailEventHooks(event_hook)
-        if isinstance(event_hook, list):
+        def _validate_event_hook_list_is_in_supported_event_hooks(
+            event_hook: Union[List[GuardrailEventHooks], List[str]],
+            supported_event_hooks: List[GuardrailEventHooks],
+        ) -> None:
             for hook in event_hook:
                 if isinstance(hook, str):
                     hook = GuardrailEventHooks(hook)
@@ -79,6 +88,23 @@ class CustomGuardrail(CustomLogger):
                     raise ValueError(
                         f"Event hook {hook} is not in the supported event hooks {supported_event_hooks}"
                     )
+
+        if event_hook is None:
+            return
+        if isinstance(event_hook, str):
+            event_hook = GuardrailEventHooks(event_hook)
+        if isinstance(event_hook, list):
+            _validate_event_hook_list_is_in_supported_event_hooks(
+                event_hook, supported_event_hooks
+            )
+        elif isinstance(event_hook, Mode):
+            _validate_event_hook_list_is_in_supported_event_hooks(
+                list(event_hook.tags.values()), supported_event_hooks
+            )
+            if event_hook.default:
+                _validate_event_hook_list_is_in_supported_event_hooks(
+                    [event_hook.default], supported_event_hooks
+                )
         elif isinstance(event_hook, GuardrailEventHooks):
             if event_hook not in supported_event_hooks:
                 raise ValueError(
@@ -89,16 +115,21 @@ class CustomGuardrail(CustomLogger):
         self, data: dict
     ) -> Union[List[str], List[Dict[str, DynamicGuardrailParams]]]:
         """
-        Returns the guardrail(s) to be run from the metadata
+        Returns the guardrail(s) to be run from the metadata or root
         """
+        if "guardrails" in data:
+            return data["guardrails"]
         metadata = data.get("metadata") or {}
         requested_guardrails = metadata.get("guardrails") or []
+        if requested_guardrails:
+            return requested_guardrails
         return requested_guardrails
 
     def _guardrail_is_in_requested_guardrails(
         self,
         requested_guardrails: Union[List[str], List[Dict[str, DynamicGuardrailParams]]],
     ) -> bool:
+
         for _guardrail in requested_guardrails:
             if isinstance(_guardrail, dict):
                 if self.guardrail_name in _guardrail:
@@ -111,7 +142,94 @@ class CustomGuardrail(CustomLogger):
 
         return False
 
-    def should_run_guardrail(self, data, event_type: GuardrailEventHooks) -> bool:
+    async def async_pre_call_deployment_hook(
+        self, kwargs: Dict[str, Any], call_type: Optional[CallTypes]
+    ) -> Optional[dict]:
+
+        from litellm.proxy._types import UserAPIKeyAuth
+
+        # should run guardrail
+        litellm_guardrails = kwargs.get("guardrails")
+        if litellm_guardrails is None or not isinstance(litellm_guardrails, list):
+            return kwargs
+
+        if (
+            self.should_run_guardrail(
+                data=kwargs, event_type=GuardrailEventHooks.pre_call
+            )
+            is not True
+        ):
+            return kwargs
+
+        # CHECK IF GUARDRAIL REJECTS THE REQUEST
+        if call_type == CallTypes.completion or call_type == CallTypes.acompletion:
+            result = await self.async_pre_call_hook(
+                user_api_key_dict=UserAPIKeyAuth(
+                    user_id=kwargs.get("user_api_key_user_id"),
+                    team_id=kwargs.get("user_api_key_team_id"),
+                    end_user_id=kwargs.get("user_api_key_end_user_id"),
+                    api_key=kwargs.get("user_api_key_hash"),
+                    request_route=kwargs.get("user_api_key_request_route"),
+                ),
+                cache=dc,
+                data=kwargs,
+                call_type=call_type.value or "acompletion",  # type: ignore
+            )
+
+            if result is not None and isinstance(result, dict):
+                result_messages = result.get("messages")
+                if result_messages is not None:  # update for any pii / masking logic
+                    kwargs["messages"] = result_messages
+
+        return kwargs
+
+    async def async_post_call_success_deployment_hook(
+        self,
+        request_data: dict,
+        response: LLMResponseTypes,
+        call_type: Optional[CallTypes],
+    ) -> Optional[LLMResponseTypes]:
+        """
+        Allow modifying / reviewing the response just after it's received from the deployment.
+        """
+        from litellm.proxy._types import UserAPIKeyAuth
+
+        # should run guardrail
+        litellm_guardrails = request_data.get("guardrails")
+        if litellm_guardrails is None or not isinstance(litellm_guardrails, list):
+            return response
+
+        if (
+            self.should_run_guardrail(
+                data=request_data, event_type=GuardrailEventHooks.post_call
+            )
+            is not True
+        ):
+            return response
+
+        # CHECK IF GUARDRAIL REJECTS THE REQUEST
+        result = await self.async_post_call_success_hook(
+            user_api_key_dict=UserAPIKeyAuth(
+                user_id=request_data.get("user_api_key_user_id"),
+                team_id=request_data.get("user_api_key_team_id"),
+                end_user_id=request_data.get("user_api_key_end_user_id"),
+                api_key=request_data.get("user_api_key_hash"),
+                request_route=request_data.get("user_api_key_request_route"),
+            ),
+            data=request_data,
+            response=response,
+        )
+
+        if result is None or not isinstance(result, get_args(LLMResponseTypes)):
+            return response
+
+        return result
+
+    def should_run_guardrail(
+        self,
+        data,
+        event_type: GuardrailEventHooks,
+    ) -> bool:
         """
         Returns True if the guardrail should be run on the event_type
         """
@@ -128,6 +246,20 @@ class CustomGuardrail(CustomLogger):
 
         if self.default_on is True:
             if self._event_hook_is_event_type(event_type):
+                if isinstance(self.event_hook, Mode):
+                    try:
+                        from litellm_enterprise.integrations.custom_guardrail import (
+                            EnterpriseCustomGuardrailHelper,
+                        )
+                    except ImportError:
+                        raise ImportError(
+                            "Setting tag-based guardrails is only available in litellm-enterprise. You must be a premium user to use this feature."
+                        )
+                    result = EnterpriseCustomGuardrailHelper._should_run_if_mode_by_tag(
+                        data, self.event_hook
+                    )
+                    if result is not None:
+                        return result
                 return True
             return False
 
@@ -141,6 +273,21 @@ class CustomGuardrail(CustomLogger):
         if not self._event_hook_is_event_type(event_type):
             return False
 
+        if isinstance(self.event_hook, Mode):
+            try:
+                from litellm_enterprise.integrations.custom_guardrail import (
+                    EnterpriseCustomGuardrailHelper,
+                )
+            except ImportError:
+                raise ImportError(
+                    "Setting tag-based guardrails is only available in litellm-enterprise. You must be a premium user to use this feature."
+                )
+            result = EnterpriseCustomGuardrailHelper._should_run_if_mode_by_tag(
+                data, self.event_hook
+            )
+            if result is not None:
+                return result
+
         return True
 
     def _event_hook_is_event_type(self, event_type: GuardrailEventHooks) -> bool:
@@ -155,6 +302,8 @@ class CustomGuardrail(CustomLogger):
             return True
         if isinstance(self.event_hook, list):
             return event_type.value in self.event_hook
+        if isinstance(self.event_hook, Mode):
+            return event_type.value in self.event_hook.tags.values()
         return self.event_hook == event_type.value
 
     def get_guardrail_dynamic_request_body_params(self, request_data: dict) -> dict:
@@ -220,9 +369,15 @@ class CustomGuardrail(CustomLogger):
         """
         if isinstance(guardrail_json_response, Exception):
             guardrail_json_response = str(guardrail_json_response)
+        from litellm.types.utils import GuardrailMode
+
         slg = StandardLoggingGuardrailInformation(
             guardrail_name=self.guardrail_name,
-            guardrail_mode=self.event_hook,
+            guardrail_mode=(
+                GuardrailMode(**self.event_hook.model_dump())  # type: ignore
+                if isinstance(self.event_hook, Mode)
+                else self.event_hook
+            ),
             guardrail_response=guardrail_json_response,
             guardrail_status=guardrail_status,
             start_time=start_time,
