@@ -231,6 +231,21 @@ def get_llm_provider(  # noqa: PLR0915
                     elif endpoint == litellm.NscaleConfig.API_BASE_URL:
                         custom_llm_provider = "nscale"
                         dynamic_api_key = litellm.NscaleConfig.get_api_key()
+                    elif endpoint == "dashscope-intl.aliyuncs.com/compatible-mode/v1":
+                        custom_llm_provider = "dashscope"
+                        dynamic_api_key = get_secret_str("DASHSCOPE_API_KEY")
+                    elif endpoint == "api.moonshot.ai/v1":
+                        custom_llm_provider = "moonshot"
+                        dynamic_api_key = get_secret_str("MOONSHOT_API_KEY")
+                    elif endpoint == "https://api.v0.dev/v1":
+                        custom_llm_provider = "v0"
+                        dynamic_api_key = get_secret_str("V0_API_KEY")
+                    elif endpoint == "https://api.lambda.ai/v1":
+                        custom_llm_provider = "lambda_ai"
+                        dynamic_api_key = get_secret_str("LAMBDA_API_KEY")
+                    elif endpoint == "https://api.hyperbolic.xyz/v1":
+                        custom_llm_provider = "hyperbolic"
+                        dynamic_api_key = get_secret_str("HYPERBOLIC_API_KEY")
 
                     if api_base is not None and not isinstance(api_base, str):
                         raise Exception(
@@ -338,6 +353,9 @@ def get_llm_provider(  # noqa: PLR0915
             custom_llm_provider = "empower"
         elif model == "*":
             custom_llm_provider = "openai"
+        # bytez models
+        elif model.startswith("bytez/"):
+            custom_llm_provider = "bytez"
         if not custom_llm_provider:
             if litellm.suppress_debug_info is False:
                 print()  # noqa
@@ -518,7 +536,7 @@ def _get_openai_compatible_provider_info(  # noqa: PLR0915
         # DataRobot is OpenAI compatible.
         (
             api_base,
-            dynamic_api_key
+            dynamic_api_key,
         ) = litellm.DataRobotConfig()._get_openai_compatible_provider_info(
             api_base, api_key
         )
@@ -658,6 +676,48 @@ def _get_openai_compatible_provider_info(  # noqa: PLR0915
         ) = litellm.NscaleConfig()._get_openai_compatible_provider_info(
             api_base=api_base, api_key=api_key
         )
+    elif custom_llm_provider == "dashscope":
+        (
+            api_base,
+            dynamic_api_key,
+        ) = litellm.DashScopeChatConfig()._get_openai_compatible_provider_info(
+            api_base, api_key
+        )
+    elif custom_llm_provider == "moonshot":
+        (
+            api_base,
+            dynamic_api_key,
+        ) = litellm.MoonshotChatConfig()._get_openai_compatible_provider_info(
+            api_base, api_key
+        )
+    elif custom_llm_provider == "v0":
+        (
+            api_base,
+            dynamic_api_key,
+        ) = litellm.V0ChatConfig()._get_openai_compatible_provider_info(
+            api_base, api_key
+        )
+    elif custom_llm_provider == "morph":
+        (
+            api_base,
+            dynamic_api_key,
+        ) = litellm.MorphChatConfig()._get_openai_compatible_provider_info(
+            api_base, api_key
+        )
+    elif custom_llm_provider == "lambda_ai":
+        (
+            api_base,
+            dynamic_api_key,
+        ) = litellm.LambdaAIChatConfig()._get_openai_compatible_provider_info(
+            api_base, api_key
+        )
+    elif custom_llm_provider == "hyperbolic":
+        (
+            api_base,
+            dynamic_api_key,
+        ) = litellm.HyperbolicChatConfig()._get_openai_compatible_provider_info(
+            api_base, api_key
+        )
 
     if api_base is not None and not isinstance(api_base, str):
         raise Exception("api base needs to be a string. api_base={}".format(api_base))
