@@ -23,6 +23,7 @@ router = APIRouter(
 if MCP_AVAILABLE:
     from litellm.proxy._experimental.mcp_server.mcp_server_manager import (
         global_mcp_server_manager,
+        _convert_protocol_version_to_enum,
     )
     from litellm.proxy._experimental.mcp_server.server import (
         ListMCPToolsRestAPIResponseObject,
@@ -149,3 +150,72 @@ if MCP_AVAILABLE:
             proxy_config=proxy_config,
         )
         return await call_mcp_tool(**data)
+    
+    ########################################################
+    # MCP Connection testing routes
+    # /health -> Test if we can connect to the MCP server
+    # /health/tools/list -> List tools from MCP server
+    # For these routes users will dynamically pass the MCP connection params, they don't need to be on the MCP registry
+    ########################################################
+    from litellm.proxy._experimental.mcp_server.server import MCPServer
+    from litellm.proxy.management_endpoints.mcp_management_endpoints import (
+        NewMCPServerRequest,
+    )
+    @router.post("/test/connection")
+    async def test_connection(
+        request: NewMCPServerRequest,
+    ):
+        """
+        Test if we can connect to the provided MCP server before adding it
+        """
+        try:
+            client = global_mcp_server_manager._create_mcp_client(
+                server=MCPServer(
+                    server_id=request.server_id or "",
+                    name=request.alias or request.server_name or "",
+                    url=request.url,
+                    transport=request.transport,
+                    spec_version=_convert_protocol_version_to_enum(request.spec_version),
+                    auth_type=request.auth_type,
+                    mcp_info=request.mcp_info,
+                ),
+                mcp_auth_header=None,
+            )
+
+            await client.connect()
+        except Exception as e:
+            verbose_logger.error(f"Error in test_connection: {e}", exc_info=True)
+            return {"status": "error", "message": "An internal error has occurred."}
+        return {"status": "ok"}
+        
+    
+    @router.post("/test/tools/list")
+    async def test_tools_list(
+        request: NewMCPServerRequest,
+        user_api_key_dict: UserAPIKeyAuth = Depends(user_api_key_auth),
+    ):
+        """
+        Preview tools available from MCP server before adding it
+        """
+        try:
+            client = global_mcp_server_manager._create_mcp_client(
+                server=MCPServer(
+                    server_id=request.server_id or "",
+                    name=request.alias or request.server_name or "",
+                    url=request.url,
+                    transport=request.transport,
+                    spec_version=_convert_protocol_version_to_enum(request.spec_version),
+                    auth_type=request.auth_type,
+                    mcp_info=request.mcp_info,
+                ),
+                mcp_auth_header=None,
+            )
+            list_tools_result = await client.list_tools()
+        except Exception as e:
+            verbose_logger.error(f"Error in test_tools_list: {e}", exc_info=True)
+            return {"status": "error", "message": "An internal error has occurred."}
+        return {
+            "tools": list_tools_result,
+            "error": None,
+            "message": "Successfully retrieved tools"
+        }
