@@ -20,7 +20,6 @@ from litellm.proxy._experimental.mcp_server.utils import (
     LITELLM_MCP_SERVER_DESCRIPTION,
     LITELLM_MCP_SERVER_NAME,
     LITELLM_MCP_SERVER_VERSION,
-    normalize_server_name,
 )
 from litellm.proxy._types import UserAPIKeyAuth
 from litellm.types.mcp_server.mcp_server_manager import MCPInfo, MCPServer
@@ -65,7 +64,7 @@ if MCP_AVAILABLE:
         global_mcp_tool_registry,
     )
     from litellm.proxy._experimental.mcp_server.utils import (
-        get_server_name_prefix_tool_mcp,
+    get_server_name_prefix_tool_mcp,
     )
 
     ######################################################
@@ -165,21 +164,38 @@ if MCP_AVAILABLE:
     ########################################################
 
     @server.list_tools()
-    async def list_tools() -> list[MCPTool]:
+    async def list_tools() -> List[MCPTool]:
         """
         List all available tools
         """
-        # Get user authentication from context variable
-        user_api_key_auth, mcp_auth_header, mcp_servers = get_auth_context()
-        verbose_logger.debug(
-            f"MCP list_tools - User API Key Auth from context: {user_api_key_auth}"
-        )
-        # Get mcp_servers from context variable
-        return await _list_mcp_tools(
-            user_api_key_auth=user_api_key_auth,
-            mcp_auth_header=mcp_auth_header,
-            mcp_servers=mcp_servers,
-        )
+        try:
+            # Get user authentication from context variable
+            user_api_key_auth, mcp_auth_header, mcp_servers, mcp_server_auth_headers, mcp_protocol_version = get_auth_context()
+            verbose_logger.debug(
+                f"MCP list_tools - User API Key Auth from context: {user_api_key_auth}"
+            )
+            verbose_logger.debug(
+                f"MCP list_tools - MCP servers from context: {mcp_servers}"
+            )
+            verbose_logger.debug(
+                f"MCP list_tools - MCP server auth headers: {list(mcp_server_auth_headers.keys()) if mcp_server_auth_headers else None}"
+            )
+            # Get mcp_servers from context variable
+            verbose_logger.debug("MCP list_tools - Calling _list_mcp_tools")
+            tools = await _list_mcp_tools(
+                user_api_key_auth=user_api_key_auth,
+                mcp_auth_header=mcp_auth_header,
+                mcp_servers=mcp_servers,
+                mcp_server_auth_headers=mcp_server_auth_headers,
+                mcp_protocol_version=mcp_protocol_version,
+            )
+            verbose_logger.info(f"MCP list_tools - Successfully returned {len(tools)} tools")
+            return tools
+        except Exception as e:
+            verbose_logger.exception(f"Error in list_tools endpoint: {str(e)}")
+            # Return empty list instead of failing completely
+            # This prevents the HTTP stream from failing and allows the client to get a response
+            return []
 
     @server.call_tool()
     async def mcp_server_tool_call(
@@ -204,7 +220,7 @@ if MCP_AVAILABLE:
         from litellm.proxy.proxy_server import proxy_config
 
         # Validate arguments
-        user_api_key_auth, mcp_auth_header, _ = get_auth_context()
+        user_api_key_auth, mcp_auth_header, _, mcp_server_auth_headers, mcp_protocol_version = get_auth_context()
 
         verbose_logger.debug(
             f"MCP mcp_server_tool_call - User API Key Auth from context: {user_api_key_auth}"
@@ -234,6 +250,8 @@ if MCP_AVAILABLE:
             response = await call_mcp_tool(
                 user_api_key_auth=user_api_key_auth,
                 mcp_auth_header=mcp_auth_header,
+                mcp_server_auth_headers=mcp_server_auth_headers,
+                mcp_protocol_version=mcp_protocol_version,
                 **data,  # for logging
             )
         except Exception as e:
@@ -254,81 +272,142 @@ if MCP_AVAILABLE:
         user_api_key_auth: Optional[UserAPIKeyAuth],
         mcp_auth_header: Optional[str],
         mcp_servers: Optional[List[str]],
+        mcp_server_auth_headers: Optional[Dict[str, str]] = None,
+        mcp_protocol_version: Optional[str] = None,
     ) -> List[MCPTool]:
         """
         Helper method to fetch tools from MCP servers based on server filtering criteria.
 
         Args:
             user_api_key_auth: User authentication info for access control
-            mcp_auth_header: Optional auth header for MCP server
-            mcp_servers: Optional list of server names to filter by
+            mcp_auth_header: Optional auth header for MCP server (deprecated)
+            mcp_servers: Optional list of server names/aliases to filter by
+            mcp_server_auth_headers: Optional dict of server-specific auth headers {server_alias: auth_value}
 
         Returns:
-            List[MCPTool]: List of tools from the specified or all allowed MCP servers
+            List[MCPTool]: Combined list of tools from filtered servers
         """
-        if mcp_servers:
-            # If mcp_servers header is present, only get tools from specified servers
-            tools = []
-            for server_id in await global_mcp_server_manager.get_allowed_mcp_servers(
-                user_api_key_auth
-            ):
-                server = global_mcp_server_manager.get_mcp_server_by_id(server_id)
-                if server and any(
-                    normalize_server_name(server.name) == normalize_server_name(s)
-                    for s in mcp_servers
-                ):
-                    server_tools = (
-                        await global_mcp_server_manager._get_tools_from_server(
-                            server=server,
-                            mcp_auth_header=mcp_auth_header,
-                        )
-                    )
-                    tools.extend(server_tools)
-            return tools
-        else:
-            # If no mcp_servers header, get tools from all allowed servers
-            return await global_mcp_server_manager.list_tools(
-                user_api_key_auth=user_api_key_auth,
-                mcp_auth_header=mcp_auth_header,
-            )
+        if not MCP_AVAILABLE:
+            return []
+
+        # Get allowed MCP servers based on user permissions
+        allowed_mcp_servers = await global_mcp_server_manager.get_allowed_mcp_servers(
+            user_api_key_auth
+        )
+
+        # Filter servers based on mcp_servers parameter if provided
+        if mcp_servers is not None:
+            # Convert to lowercase for case-insensitive comparison
+            mcp_servers_lower = [s.lower() for s in mcp_servers]
+            allowed_mcp_servers = [
+                server_id
+                for server_id in allowed_mcp_servers
+                if any(
+                    server_alias.lower() in mcp_servers_lower
+                    for server in [global_mcp_server_manager.get_mcp_server_by_id(server_id)]
+                    if server is not None
+                    for server_alias in [
+                        server.alias,
+                        server.server_name,
+                        server_id,
+                    ]
+                    if server_alias is not None
+                )
+            ]
+
+        # Get tools from each allowed server
+        all_tools = []
+        for server_id in allowed_mcp_servers:
+            server = global_mcp_server_manager.get_mcp_server_by_id(server_id)
+            if server is None:
+                continue
+
+            # Get server-specific auth header if available
+            server_auth_header = None
+            if mcp_server_auth_headers and server.alias is not None:
+                server_auth_header = mcp_server_auth_headers.get(server.alias)
+            elif mcp_server_auth_headers and server.server_name is not None:
+                server_auth_header = mcp_server_auth_headers.get(server.server_name)
+            
+            # Fall back to deprecated mcp_auth_header if no server-specific header found
+            if server_auth_header is None:
+                server_auth_header = mcp_auth_header
+
+            try:
+                tools = await global_mcp_server_manager._get_tools_from_server(
+                    server=server,
+                    mcp_auth_header=server_auth_header,
+                    mcp_protocol_version=mcp_protocol_version,
+                )
+                all_tools.extend(tools)
+                verbose_logger.debug(f"Successfully fetched {len(tools)} tools from server {server.name}")
+            except Exception as e:
+                verbose_logger.exception(
+                    f"Error getting tools from server {server.name}: {str(e)}"
+                )
+                # Continue with other servers instead of failing completely
+
+        verbose_logger.info(f"Successfully fetched {len(all_tools)} tools total from all MCP servers")
+        return all_tools
 
     async def _list_mcp_tools(
         user_api_key_auth: Optional[UserAPIKeyAuth] = None,
         mcp_auth_header: Optional[str] = None,
         mcp_servers: Optional[List[str]] = None,
+        mcp_server_auth_headers: Optional[Dict[str, str]] = None,
+        mcp_protocol_version: Optional[str] = None,
     ) -> List[MCPTool]:
         """
-        List all available tools
+        List all available MCP tools.
 
         Args:
             user_api_key_auth: User authentication info for access control
-            mcp_auth_header: Optional auth header for MCP server
-            mcp_servers: Optional list of server names to filter by
+            mcp_auth_header: Optional auth header for MCP server (deprecated)
+            mcp_servers: Optional list of server names/aliases to filter by
+            mcp_server_auth_headers: Optional dict of server-specific auth headers {server_alias: auth_value}
+
+        Returns:
+            List[MCPTool]: Combined list of tools from all accessible servers
         """
-        tools = []
-        for tool in global_mcp_tool_registry.list_tools():
-            tools.append(
-                MCPTool(
+        if not MCP_AVAILABLE:
+            return []
+        # Get tools from managed MCP servers with error handling
+        managed_tools = []
+        try:
+            managed_tools = await _get_tools_from_mcp_servers(
+                user_api_key_auth=user_api_key_auth,
+                mcp_auth_header=mcp_auth_header,
+                mcp_servers=mcp_servers,
+                mcp_server_auth_headers=mcp_server_auth_headers,
+                mcp_protocol_version=mcp_protocol_version,
+            )
+            verbose_logger.debug(f"Successfully fetched {len(managed_tools)} tools from managed MCP servers")
+        except Exception as e:
+            verbose_logger.exception(f"Error getting tools from managed MCP servers: {str(e)}")
+            # Continue with empty managed tools list instead of failing completely
+
+        # Get tools from local registry
+        local_tools = []
+        try:
+            local_tools_raw = global_mcp_tool_registry.list_tools()
+            
+            # Convert local tools to MCPTool format
+            for tool in local_tools_raw:
+                # Convert from litellm.types.mcp_server.tool_registry.MCPTool to mcp.types.Tool
+                mcp_tool = MCPTool(
                     name=tool.name,
                     description=tool.description,
-                    inputSchema=tool.input_schema,
+                    inputSchema=tool.input_schema
                 )
-            )
-        verbose_logger.debug(
-            "GLOBAL MCP TOOLS: %s", global_mcp_tool_registry.list_tools()
-        )
+                local_tools.append(mcp_tool)
+        except Exception as e:
+            verbose_logger.exception(f"Error getting tools from local registry: {str(e)}")
+            # Continue with empty local tools list instead of failing completely
 
-        # Get tools from MCP servers
-        tools_from_mcp_servers = await _get_tools_from_mcp_servers(
-            user_api_key_auth=user_api_key_auth,
-            mcp_auth_header=mcp_auth_header,
-            mcp_servers=mcp_servers,
-        )
+        # Combine all tools
+        all_tools = managed_tools + local_tools
 
-        verbose_logger.debug("TOOLS FROM MCP SERVERS: %s", tools_from_mcp_servers)
-        if tools_from_mcp_servers is not None:
-            tools.extend(tools_from_mcp_servers)
-        return tools
+        return all_tools
 
     @client
     async def call_mcp_tool(
@@ -336,6 +415,8 @@ if MCP_AVAILABLE:
             arguments: Optional[Dict[str, Any]] = None,
             user_api_key_auth: Optional[UserAPIKeyAuth] = None,
             mcp_auth_header: Optional[str] = None,
+            mcp_server_auth_headers: Optional[Dict[str, str]] = None,
+            mcp_protocol_version: Optional[str] = None,
             **kwargs: Any
     ) -> List[Union[TextContent, ImageContent, EmbeddedResource]]:
         """
@@ -382,6 +463,9 @@ if MCP_AVAILABLE:
                 arguments=arguments,
                 user_api_key_auth=user_api_key_auth,
                 mcp_auth_header=mcp_auth_header,
+                mcp_server_auth_headers=mcp_server_auth_headers,
+                mcp_protocol_version=mcp_protocol_version,
+                litellm_logging_obj=litellm_logging_obj,
             )
 
         # Fall back to local tool registry (use original name)
@@ -432,13 +516,21 @@ if MCP_AVAILABLE:
         arguments: Dict[str, Any],
         user_api_key_auth: Optional[UserAPIKeyAuth] = None,
         mcp_auth_header: Optional[str] = None,
+        mcp_server_auth_headers: Optional[Dict[str, str]] = None,
+        mcp_protocol_version: Optional[str] = None,
+        litellm_logging_obj: Optional[Any] = None,
     ) -> List[Union[TextContent, ImageContent, EmbeddedResource]]:
         """Handle tool execution for managed server tools"""
+        # Import here to avoid circular import
+        from litellm.proxy.proxy_server import proxy_logging_obj
+        
         call_tool_result = await global_mcp_server_manager.call_tool(
             name=name,
             arguments=arguments,
             user_api_key_auth=user_api_key_auth,
             mcp_auth_header=mcp_auth_header,
+            mcp_server_auth_headers=mcp_server_auth_headers,
+            proxy_logging_obj=proxy_logging_obj,
         )
         verbose_logger.debug("CALL TOOL RESULT: %s", call_tool_result)
         return call_tool_result.content  # type: ignore[return-value]
@@ -460,21 +552,47 @@ if MCP_AVAILABLE:
         except Exception as e:
             return [TextContent(text=f"Error: {str(e)}", type="text")]
 
+    async def extract_mcp_auth_context(scope, path):
+        """
+        Extracts mcp_servers from the path and processes the MCP request for auth context.
+        Returns: (user_api_key_auth, mcp_auth_header, mcp_servers, mcp_server_auth_headers)
+        """
+        import re
+        mcp_servers_from_path = None
+        mcp_path_match = re.match(r"^/mcp/([^/]+)(/.*)?$", path)
+        if mcp_path_match:
+            mcp_servers_str = mcp_path_match.group(1)
+            if mcp_servers_str:
+                mcp_servers_from_path = [s.strip() for s in mcp_servers_str.split(",") if s.strip()]
+
+        if mcp_servers_from_path is not None:
+            user_api_key_auth, mcp_auth_header, _, mcp_server_auth_headers, mcp_protocol_version = (
+                await MCPRequestHandler.process_mcp_request(scope)
+            )
+            mcp_servers = mcp_servers_from_path
+        else:
+            user_api_key_auth, mcp_auth_header, mcp_servers, mcp_server_auth_headers, mcp_protocol_version = (
+                await MCPRequestHandler.process_mcp_request(scope)
+            )
+        return user_api_key_auth, mcp_auth_header, mcp_servers, mcp_server_auth_headers, mcp_protocol_version
+
     async def handle_streamable_http_mcp(
         scope: Scope, receive: Receive, send: Send
     ) -> None:
         """Handle MCP requests through StreamableHTTP."""
         try:
-            # Validate headers and log request info
-            user_api_key_auth, mcp_auth_header, mcp_servers = (
-                await MCPRequestHandler.process_mcp_request(scope)
-            )
-            verbose_logger.debug(f"MCP request headers - mcp_servers: {mcp_servers}")
+            path = scope.get("path", "")
+            user_api_key_auth, mcp_auth_header, mcp_servers, mcp_server_auth_headers, mcp_protocol_version = await extract_mcp_auth_context(scope, path)
+            verbose_logger.debug(f"MCP request mcp_servers (header/path): {mcp_servers}")
+            verbose_logger.debug(f"MCP server auth headers: {list(mcp_server_auth_headers.keys()) if mcp_server_auth_headers else None}")
+            verbose_logger.debug(f"MCP protocol version: {mcp_protocol_version}")
             # Set the auth context variable for easy access in MCP functions
             set_auth_context(
                 user_api_key_auth=user_api_key_auth,
                 mcp_auth_header=mcp_auth_header,
                 mcp_servers=mcp_servers,
+                mcp_server_auth_headers=mcp_server_auth_headers,
+                mcp_protocol_version=mcp_protocol_version,
             )
 
             # Ensure session managers are initialized
@@ -486,32 +604,60 @@ if MCP_AVAILABLE:
             await session_manager.handle_request(scope, receive, send)
         except Exception as e:
             verbose_logger.exception(f"Error handling MCP request: {e}")
-            raise e
+            # Instead of re-raising, try to send a graceful error response
+            try:
+                # Send a proper HTTP error response instead of letting the exception bubble up
+                from starlette.responses import JSONResponse
+                from starlette.status import HTTP_500_INTERNAL_SERVER_ERROR
+                
+                error_response = JSONResponse(
+                    status_code=HTTP_500_INTERNAL_SERVER_ERROR,
+                    content={"error": "MCP request failed", "details": str(e)}
+                )
+                await error_response(scope, receive, send)
+            except Exception as response_error:
+                verbose_logger.exception(f"Failed to send error response: {response_error}")
+                # If we can't send a proper response, re-raise the original error
+                raise e
 
     async def handle_sse_mcp(scope: Scope, receive: Receive, send: Send) -> None:
         """Handle MCP requests through SSE."""
         try:
-            # Validate headers and log request info
-            user_api_key_auth, mcp_auth_header, mcp_servers = (
-                await MCPRequestHandler.process_mcp_request(scope)
-            )
-            # Set the auth context variable for easy access in MCP functions
+            path = scope.get("path", "")
+            user_api_key_auth, mcp_auth_header, mcp_servers, mcp_server_auth_headers, mcp_protocol_version = await extract_mcp_auth_context(scope, path)
+            verbose_logger.debug(f"MCP request mcp_servers (header/path): {mcp_servers}")
+            verbose_logger.debug(f"MCP server auth headers: {list(mcp_server_auth_headers.keys()) if mcp_server_auth_headers else None}")
+            verbose_logger.debug(f"MCP protocol version: {mcp_protocol_version}")
             set_auth_context(
                 user_api_key_auth=user_api_key_auth,
                 mcp_auth_header=mcp_auth_header,
                 mcp_servers=mcp_servers,
+                mcp_server_auth_headers=mcp_server_auth_headers,
+                mcp_protocol_version=mcp_protocol_version,
             )
 
-            # Ensure session managers are initialized
             if not _SESSION_MANAGERS_INITIALIZED:
                 await initialize_session_managers()
-                # Give it a moment to start up
                 await asyncio.sleep(0.1)
 
             await sse_session_manager.handle_request(scope, receive, send)
         except Exception as e:
             verbose_logger.exception(f"Error handling MCP request: {e}")
-            raise e
+            # Instead of re-raising, try to send a graceful error response
+            try:
+                # Send a proper HTTP error response instead of letting the exception bubble up
+                from starlette.responses import JSONResponse
+                from starlette.status import HTTP_500_INTERNAL_SERVER_ERROR
+                
+                error_response = JSONResponse(
+                    status_code=HTTP_500_INTERNAL_SERVER_ERROR,
+                    content={"error": "MCP request failed", "details": str(e)}
+                )
+                await error_response(scope, receive, send)
+            except Exception as response_error:
+                verbose_logger.exception(f"Failed to send error response: {response_error}")
+                # If we can't send a proper response, re-raise the original error
+                raise e
 
     app = FastAPI(
         title=LITELLM_MCP_SERVER_NAME,
@@ -544,30 +690,36 @@ if MCP_AVAILABLE:
         user_api_key_auth: UserAPIKeyAuth,
         mcp_auth_header: Optional[str] = None,
         mcp_servers: Optional[List[str]] = None,
+        mcp_server_auth_headers: Optional[Dict[str, str]] = None,
+        mcp_protocol_version: Optional[str] = None,
     ) -> None:
         """
         Set the UserAPIKeyAuth in the auth context variable.
 
         Args:
             user_api_key_auth: UserAPIKeyAuth object
-            mcp_auth_header: MCP auth header to be passed to the MCP server
-            mcp_servers: Optional list of server names to filter by
+            mcp_auth_header: MCP auth header to be passed to the MCP server (deprecated)
+            mcp_servers: Optional list of server names and access groups to filter by
+            mcp_server_auth_headers: Optional dict of server-specific auth headers {server_alias: auth_value}
         """
         auth_user = MCPAuthenticatedUser(
             user_api_key_auth=user_api_key_auth,
             mcp_auth_header=mcp_auth_header,
             mcp_servers=mcp_servers,
+            mcp_server_auth_headers=mcp_server_auth_headers,
+            mcp_protocol_version=mcp_protocol_version,
         )
         auth_context_var.set(auth_user)
 
     def get_auth_context() -> (
-        Tuple[Optional[UserAPIKeyAuth], Optional[str], Optional[List[str]]]
+        Tuple[Optional[UserAPIKeyAuth], Optional[str], Optional[List[str]], Optional[Dict[str, str]], Optional[str]]
     ):
         """
         Get the UserAPIKeyAuth from the auth context variable.
 
         Returns:
-            Tuple[Optional[UserAPIKeyAuth], Optional[str]]: UserAPIKeyAuth object and MCP auth header
+            Tuple[Optional[UserAPIKeyAuth], Optional[str], Optional[List[str]], Optional[Dict[str, str]]]: 
+            UserAPIKeyAuth object, MCP auth header (deprecated), MCP servers (can include access groups), and server-specific auth headers
         """
         auth_user = auth_context_var.get()
         if auth_user and isinstance(auth_user, MCPAuthenticatedUser):
@@ -575,8 +727,10 @@ if MCP_AVAILABLE:
                 auth_user.user_api_key_auth,
                 auth_user.mcp_auth_header,
                 auth_user.mcp_servers,
+                auth_user.mcp_server_auth_headers,
+                auth_user.mcp_protocol_version,
             )
-        return None, None, None
+        return None, None, None, None, None
 
     ########################################################
     ############ End of Auth Context Functions #############
