@@ -117,6 +117,7 @@ async def create_streaming_response(
         first_chunk_value = await generator.__anext__()
 
         if first_chunk_value is not None:
+
             try:
                 error_code_from_chunk = await _parse_event_data_for_error(
                     first_chunk_value
@@ -130,6 +131,7 @@ async def create_streaming_response(
                 verbose_proxy_logger.debug(f"Error parsing first chunk value: {e}")
 
     except StopAsyncIteration:
+
         # Generator was empty. Default status
         async def empty_gen() -> AsyncGenerator[str, None]:
             if False:
@@ -142,6 +144,7 @@ async def create_streaming_response(
             status_code=default_status_code,
         )
     except Exception as e:
+
         # Unexpected error consuming first chunk.
         verbose_proxy_logger.exception(
             f"Error consuming first chunk from generator: {e}"
@@ -273,6 +276,8 @@ class ProxyBaseLLMRequestProcessing:
             "agenerate_content",
             "agenerate_content_stream",
             "allm_passthrough_route",
+            "avector_store_search",
+            "avector_store_create",
         ],
         version: Optional[str] = None,
         user_model: Optional[str] = None,
@@ -357,6 +362,8 @@ class ProxyBaseLLMRequestProcessing:
             "agenerate_content",
             "agenerate_content_stream",
             "allm_passthrough_route",
+            "avector_store_search",
+            "avector_store_create",
         ],
         proxy_logging_obj: ProxyLogging,
         general_settings: dict,
@@ -450,6 +457,7 @@ class ProxyBaseLLMRequestProcessing:
         ) or self._is_streaming_response(
             response
         ):  # use generate_responses to stream responses
+
             custom_headers = ProxyBaseLLMRequestProcessing.get_custom_headers(
                 user_api_key_dict=user_api_key_dict,
                 call_id=logging_obj.litellm_call_id,
@@ -488,6 +496,7 @@ class ProxyBaseLLMRequestProcessing:
                         headers=custom_headers,
                     )
             else:
+
                 selected_data_generator = select_data_generator(
                     response=response,
                     user_api_key_dict=user_api_key_dict,
@@ -721,8 +730,11 @@ class ProxyBaseLLMRequestProcessing:
         """
         Anthropic /messages and Google /generateContent streaming data generator require SSE events
         """
+        from litellm.types.utils import ModelResponse, ModelResponseStream
+
         verbose_proxy_logger.debug("inside generator")
         try:
+            str_so_far = ""
             async for chunk in response:
                 verbose_proxy_logger.debug(
                     "async_data_generator: received streaming chunk - {}".format(chunk)
@@ -732,8 +744,13 @@ class ProxyBaseLLMRequestProcessing:
                     user_api_key_dict=user_api_key_dict,
                     response=chunk,
                     data=request_data,
+                    str_so_far=str_so_far,
                 )
 
+                if isinstance(chunk, (ModelResponse, ModelResponseStream)):
+                    response_str = litellm.get_response_string(response_obj=chunk)
+                    str_so_far += response_str
+
                 # Format chunk using helper function
                 yield ProxyBaseLLMRequestProcessing.return_sse_chunk(chunk)
         except Exception as e:
