@@ -12,6 +12,7 @@ These are members of a Team on LiteLLM
 """
 
 import asyncio
+import json
 import traceback
 import uuid
 from datetime import datetime, timezone
@@ -43,7 +44,10 @@ from litellm.types.proxy.management_endpoints.common_daily_activity import (
     SpendMetrics,
 )
 from litellm.types.proxy.management_endpoints.internal_user_endpoints import (
+    BulkUpdateUserRequest,
+    BulkUpdateUserResponse,
     UserListResponse,
+    UserUpdateResult,
 )
 
 if TYPE_CHECKING:
@@ -119,13 +123,15 @@ async def _check_duplicate_user_email(
             raise Exception("Database not connected")
 
         existing_user = await prisma_client.db.litellm_usertable.find_first(
-            where={"user_email": user_email.strip()}
+            where={"user_email": {"equals": user_email.strip(), "mode": "insensitive"}}
         )
 
         if existing_user is not None:
             raise HTTPException(
                 status_code=400,
-                detail={"error": f"User with email {user_email} already exists"},
+                detail={
+                    "error": f"User with email {existing_user.user_email} already exists"
+                },
             )
 
 
@@ -246,6 +252,36 @@ def check_if_default_team_set() -> Optional[Union[List[str], List[NewUserRequest
     return None
 
 
+async def add_new_user_to_default_team(
+    user_id: str,
+    user_email: Optional[str],
+    user_api_key_dict: UserAPIKeyAuth,
+    teams: Union[List[str], List[NewUserRequestTeam]],
+    prisma_client: "PrismaClient",
+):
+    tasks = []
+    for team in teams:
+        user_role: Literal["user", "admin"] = "user"
+        if isinstance(team, str):
+            team_id = team
+        elif isinstance(team, NewUserRequestTeam):
+            team_id = team.team_id
+            user_role = team.user_role
+        else:
+            raise ValueError(f"Invalid team type: {type(team)}")
+
+        tasks.append(
+            _add_user_to_team(
+                user_id=user_id,
+                team_id=team_id,
+                user_email=user_email,
+                user_api_key_dict=user_api_key_dict,
+                user_role=user_role,
+            )
+        )
+    await asyncio.gather(*tasks, return_exceptions=True)
+
+
 @router.post(
     "/user/new",
     tags=["Internal User management"],
@@ -362,30 +398,13 @@ async def new_user(
                 user_role="user",
             )
         elif teams is not None:
-            tasks = []
-            for team in teams:
-                max_budget_in_team: Optional[float] = None
-                user_role: Literal["user", "admin"] = "user"
-                if isinstance(team, str):
-                    team_id = team
-                elif isinstance(team, NewUserRequestTeam):
-                    team_id = team.team_id
-                    max_budget_in_team = team.max_budget_in_team
-                    user_role = team.user_role
-                else:
-                    raise ValueError(f"Invalid team type: {type(team)}")
-
-                tasks.append(
-                    _add_user_to_team(
-                        user_id=cast(str, response.get("user_id")),
-                        team_id=team_id,
-                        user_email=data.user_email,
-                        user_api_key_dict=user_api_key_dict,
-                        max_budget_in_team=max_budget_in_team,
-                        user_role=user_role,
-                    )
-                )
-            await asyncio.gather(*tasks, return_exceptions=True)
+            await add_new_user_to_default_team(
+                user_id=cast(str, response.get("user_id")),
+                user_email=data.user_email,
+                user_api_key_dict=user_api_key_dict,
+                teams=teams,
+                prisma_client=prisma_client,
+            )
 
         user_id = cast(Optional[str], response.get("user_id", None))
 
@@ -726,7 +745,9 @@ def _process_keys_for_user_info(
     return returned_keys
 
 
-def _update_internal_user_params(data_json: dict, data: UpdateUserRequest) -> dict:
+def _update_internal_user_params(
+    data_json: dict, data: Union[UpdateUserRequest, UpdateUserRequestNoUserIDorEmail]
+) -> dict:
     non_default_values = {}
     for k, v in data_json.items():
         if (
@@ -773,6 +794,143 @@ def _update_internal_user_params(data_json: dict, data: UpdateUserRequest) -> di
     return non_default_values
 
 
+async def _update_single_user_helper(
+    user_request: UpdateUserRequest,
+    user_api_key_dict: UserAPIKeyAuth,
+    litellm_changed_by: Optional[str] = None,
+) -> Dict[str, Any]:
+    """
+    Helper function to update a single user.
+    Used by both user_update and bulk_user_update endpoints.
+
+    Returns the updated user data or raises an exception on failure.
+    """
+    from litellm.proxy.proxy_server import litellm_proxy_admin_name, prisma_client
+
+    if prisma_client is None:
+        raise Exception("Not connected to DB!")
+
+    # Validate user identifier
+    if not user_request.user_id and not user_request.user_email:
+        raise ValueError("Either user_id or user_email must be provided")
+
+    # Convert to data format expected by update logic
+    data_json: dict = user_request.model_dump(exclude_unset=True)
+
+    # Apply update transformations (reuse existing logic)
+    non_default_values = _update_internal_user_params(
+        data_json=data_json, data=user_request
+    )
+
+    # Get existing user data for audit logging and metadata preparation
+    existing_user_row: Optional[BaseModel] = None
+    if user_request.user_id:
+        existing_user_row = await prisma_client.db.litellm_usertable.find_first(
+            where={"user_id": user_request.user_id}
+        )
+    elif user_request.user_email:
+        existing_user_row = await prisma_client.db.litellm_usertable.find_first(
+            where={"user_email": user_request.user_email}
+        )
+
+    if existing_user_row is not None:
+        existing_user_row = LiteLLM_UserTable(
+            **existing_user_row.model_dump(exclude_none=True)
+        )
+
+    existing_metadata = (
+        cast(Dict, getattr(existing_user_row, "metadata", {}) or {})
+        if existing_user_row is not None
+        else {}
+    )
+
+    non_default_values = prepare_metadata_fields(
+        data=user_request,
+        non_default_values=non_default_values,
+        existing_metadata=existing_metadata or {},
+    )
+
+    # Perform the update
+    response: Optional[Dict[str, Any]] = None
+
+    if user_request.user_id and len(user_request.user_id) > 0:
+        non_default_values["user_id"] = user_request.user_id
+        response = await prisma_client.update_data(
+            user_id=user_request.user_id,
+            data=non_default_values,
+            table_name="user",
+        )
+    elif user_request.user_email:
+        # Handle email-based updates
+        existing_user_rows = await prisma_client.get_data(
+            key_val={"user_email": user_request.user_email},
+            table_name="user",
+            query_type="find_all",
+        )
+
+        if (
+            existing_user_rows
+            and isinstance(existing_user_rows, list)
+            and len(existing_user_rows) > 0
+        ):
+            for existing_user in existing_user_rows:
+                non_default_values["user_id"] = existing_user.user_id
+                response = await prisma_client.update_data(
+                    user_id=existing_user.user_id,
+                    data=non_default_values,
+                    table_name="user",
+                )
+                break  # Update first matching user
+        else:
+            # Create new user if not found
+            non_default_values["user_id"] = str(uuid.uuid4())
+            non_default_values["user_email"] = user_request.user_email
+            response = await prisma_client.insert_data(
+                data=non_default_values, table_name="user"
+            )
+
+    # Create audit log for successful update
+    if response is not None:
+        try:
+            updated_user_row = await prisma_client.db.litellm_usertable.find_first(
+                where={"user_id": response["user_id"]}
+            )
+
+            if updated_user_row:
+                user_row_typed = LiteLLM_UserTable(
+                    **updated_user_row.model_dump(exclude_none=True)
+                )
+
+                # Create audit log asynchronously
+                asyncio.create_task(
+                    UserManagementEventHooks.create_internal_user_audit_log(
+                        user_id=user_row_typed.user_id,
+                        action="updated",
+                        litellm_changed_by=litellm_changed_by
+                        or user_api_key_dict.user_id,
+                        user_api_key_dict=user_api_key_dict,
+                        litellm_proxy_admin_name=litellm_proxy_admin_name,
+                        before_value=(
+                            existing_user_row.model_dump_json(exclude_none=True)
+                            if existing_user_row
+                            else None
+                        ),
+                        after_value=user_row_typed.model_dump_json(exclude_none=True),
+                    )
+                )
+        except Exception as audit_error:
+            verbose_proxy_logger.warning(
+                f"Failed to create audit log for user {response.get('user_id')}: {audit_error}"
+            )
+
+    if response is None:
+        raise HTTPException(
+            status_code=400,
+            detail={"error": "Failed to update user"},
+        )
+    return response
+
+
 @router.post(
     "/user/update",
     tags=["Internal User management"],
@@ -829,116 +987,13 @@ async def user_update(
         - object_permission: Optional[LiteLLM_ObjectPermissionBase] - internal user-specific object permission. Example - {"vector_stores": ["vector_store_1", "vector_store_2"]}. IF null or {} then no object permission.
     
     """
-    from litellm.proxy.proxy_server import litellm_proxy_admin_name, prisma_client
-
     try:
-        data_json: dict = data.model_dump(exclude_unset=True)
-        # get the row from db
-        if prisma_client is None:
-            raise Exception("Not connected to DB!")
-
-        # get non default values for key
-        non_default_values = _update_internal_user_params(
-            data_json=data_json, data=data
-        )
-
-        existing_user_row: Optional[BaseModel] = None
-        if data.user_id is not None:
-            existing_user_row = await prisma_client.db.litellm_usertable.find_first(
-                where={"user_id": data.user_id}
-            )
-            if existing_user_row is not None:
-                existing_user_row = LiteLLM_UserTable(
-                    **existing_user_row.model_dump(exclude_none=True)
-                )
-
-        existing_metadata = (
-            cast(Dict, getattr(existing_user_row, "metadata", {}) or {})
-            if existing_user_row is not None
-            else {}
-        )
-
-        non_default_values = prepare_metadata_fields(
-            data=data,
-            non_default_values=non_default_values,
-            existing_metadata=existing_metadata or {},
-        )
-
-        ## ADD USER, IF NEW ##
         verbose_proxy_logger.debug("/user/update: Received data = %s", data)
-        response: Optional[Any] = None
-        if data.user_id is not None and len(data.user_id) > 0:
-            non_default_values["user_id"] = data.user_id  # type: ignore
-            verbose_proxy_logger.debug("In update user, user_id condition block.")
-            response = await prisma_client.update_data(
-                user_id=data.user_id,
-                data=non_default_values,
-                table_name="user",
-            )
-            verbose_proxy_logger.debug(
-                f"received response from updating prisma client. response={response}"
-            )
-        elif data.user_email is not None:
-            non_default_values["user_id"] = str(uuid.uuid4())
-            non_default_values["user_email"] = data.user_email
-            ## user email is not unique acc. to prisma schema -> future improvement
-            ### for now: check if it exists in db, if not - insert it
-            existing_user_rows = await prisma_client.get_data(
-                key_val={"user_email": data.user_email},
-                table_name="user",
-                query_type="find_all",
-            )
-            if existing_user_rows is None or (
-                isinstance(existing_user_rows, list) and len(existing_user_rows) == 0
-            ):
-                response = await prisma_client.insert_data(
-                    data=non_default_values, table_name="user"
-                )
-            elif isinstance(existing_user_rows, list) and len(existing_user_rows) > 0:
-                for existing_user in existing_user_rows:
-                    response = await prisma_client.update_data(
-                        user_id=existing_user.user_id,
-                        data=non_default_values,
-                        table_name="user",
-                    )
-
-        if response is not None:  # emit audit log
-            try:
-                user_row: BaseModel = (
-                    await prisma_client.db.litellm_usertable.find_first(
-                        where={"user_id": response["user_id"]}
-                    )
-                )
-
-                user_row_litellm_typed = LiteLLM_UserTable(
-                    **user_row.model_dump(exclude_none=True)
-                )
-
-                asyncio.create_task(
-                    UserManagementEventHooks.create_internal_user_audit_log(
-                        user_id=user_row_litellm_typed.user_id,
-                        action="updated",
-                        litellm_changed_by=user_api_key_dict.user_id,
-                        user_api_key_dict=user_api_key_dict,
-                        litellm_proxy_admin_name=litellm_proxy_admin_name,
-                        before_value=(
-                            existing_user_row.model_dump_json(exclude_none=True)
-                            if existing_user_row
-                            else None
-                        ),
-                        after_value=user_row_litellm_typed.model_dump_json(
-                            exclude_none=True
-                        ),
-                    )
-                )
-            except Exception as e:
-                verbose_proxy_logger.warning(
-                    "Unable to create audit log for user on `/user/update` - {}".format(
-                        str(e)
-                    )
-                )
-        return response  # type: ignore
-        # update based on remaining passed in values
+        response = await _update_single_user_helper(
+            user_request=data,
+            user_api_key_dict=user_api_key_dict,
+        )
+        return response
     except Exception as e:
         verbose_proxy_logger.exception(
             "litellm.proxy.proxy_server.user_update(): Exception occured - {}".format(
@@ -963,6 +1018,271 @@ async def user_update(
         )
 
 
+async def bulk_update_processed_users(
+    users_to_update: List[UpdateUserRequest],
+    user_api_key_dict: UserAPIKeyAuth,
+    litellm_changed_by: Optional[str] = None,
+) -> BulkUpdateUserResponse:
+    results: List[UserUpdateResult] = []
+    successful_updates = 0
+    failed_updates = 0
+
+    # Process each user update independently
+    try:
+        for user_request in users_to_update:
+            try:
+                response = await _update_single_user_helper(
+                    user_request=user_request,
+                    user_api_key_dict=user_api_key_dict,
+                    litellm_changed_by=litellm_changed_by,
+                )
+                # Record success
+                results.append(
+                    UserUpdateResult(
+                        user_id=(
+                            response.get("user_id")
+                            if response
+                            else user_request.user_id
+                        ),
+                        user_email=user_request.user_email,
+                        success=True,
+                        updated_user=response,
+                    )
+                )
+                successful_updates += 1
+            except Exception as e:
+                verbose_proxy_logger.exception(
+                    f"Failed to update user {user_request.user_id or user_request.user_email}: {e}"
+                )
+                # Record failure
+                error_message = str(e)
+                verbose_proxy_logger.error(
+                    f"Failed to update user {user_request.user_id or user_request.user_email}: {error_message}"
+                )
+
+                results.append(
+                    UserUpdateResult(
+                        user_id=user_request.user_id,
+                        user_email=user_request.user_email,
+                        success=False,
+                        error=error_message,
+                    )
+                )
+                failed_updates += 1
+
+        return BulkUpdateUserResponse(
+            results=results,
+            total_requested=len(users_to_update),
+            successful_updates=successful_updates,
+            failed_updates=failed_updates,
+        )
+    except Exception as e:
+        verbose_proxy_logger.exception(f"Failed to update users: {e}")
+        raise HTTPException(status_code=500, detail={"error": str(e)})
+
+
+@router.post(
+    "/user/bulk_update",
+    tags=["Internal User management"],
+    dependencies=[Depends(user_api_key_auth)],
+    response_model=BulkUpdateUserResponse,
+)
+@management_endpoint_wrapper
+async def bulk_user_update(
+    data: BulkUpdateUserRequest,
+    user_api_key_dict: UserAPIKeyAuth = Depends(user_api_key_auth),
+    litellm_changed_by: Optional[str] = Header(
+        None,
+        description="The litellm-changed-by header enables tracking of actions performed by authorized users on behalf of other users, providing an audit trail for accountability",
+    ),
+):
+    """
+    Bulk update multiple users at once.
+    
+    This endpoint allows updating multiple users in a single request. Each user update
+    is processed independently - if some updates fail, others will still succeed.
+    
+    Parameters:
+    - users: Optional[List[UpdateUserRequest]] - List of specific user update requests
+    - all_users: Optional[bool] - Set to true to update all users in the system
+    - user_updates: Optional[UpdateUserRequest] - Updates to apply when all_users=True
+    
+    Returns:
+    - results: List of individual update results
+    - total_requested: Total number of users requested for update
+    - successful_updates: Number of successful updates
+    - failed_updates: Number of failed updates
+    
+    Example request for specific users:
+    ```bash
+    curl --location 'http://0.0.0.0:4000/user/bulk_update' \
+    --header 'Authorization: Bearer sk-1234' \
+    --header 'Content-Type: application/json' \
+    --data '{
+        "users": [
+            {
+                "user_id": "user1",
+                "user_role": "internal_user",
+                "max_budget": 100.0
+            },
+            {
+                "user_email": "user2@example.com", 
+                "user_role": "internal_user_viewer",
+                "max_budget": 50.0
+            }
+        ]
+    }'
+    ```
+    
+    Example request for all users:
+    ```bash
+    curl --location 'http://0.0.0.0:4000/user/bulk_update' \
+    --header 'Authorization: Bearer sk-1234' \
+    --header 'Content-Type: application/json' \
+    --data '{
+        "all_users": true,
+        "user_updates": {
+            "user_role": "internal_user",
+            "max_budget": 50.0
+        }
+    }'
+    ```
+    """
+    from litellm.proxy.proxy_server import litellm_proxy_admin_name, prisma_client
+
+    if prisma_client is None:
+        raise HTTPException(
+            status_code=500,
+            detail={"error": "Database not connected"},
+        )
+
+    # Determine the list of users to update
+    users_to_update: Union[
+        List[UpdateUserRequest], List[UpdateUserRequestNoUserIDorEmail]
+    ] = []
+
+    if data.all_users and data.user_updates:
+        # Optimized path for updating all users directly in database
+        all_users_in_db = await prisma_client.db.litellm_usertable.find_many(
+            order={"created_at": "desc"}
+        )
+
+        if not all_users_in_db:
+            raise HTTPException(
+                status_code=400,
+                detail={"error": "No users found to update"},
+            )
+
+        # Limit batch size to prevent overwhelming the system
+        MAX_BATCH_SIZE = 500  # Increased limit for all-users operations
+        if len(all_users_in_db) > MAX_BATCH_SIZE:
+            raise HTTPException(
+                status_code=400,
+                detail={
+                    "error": f"Maximum {MAX_BATCH_SIZE} users can be updated at once. Found {len(all_users_in_db)} users."
+                },
+            )
+
+        # Apply update transformations (reuse existing logic)
+        data_json: dict = data.user_updates.model_dump(exclude_unset=True)
+        non_default_values = _update_internal_user_params(
+            data_json=data_json, data=data.user_updates
+        )
+
+        # Remove user identification fields since we're updating by user_id
+        non_default_values.pop("user_id", None)
+        non_default_values.pop("user_email", None)
+
+        successful_updates = 0
+        failed_updates = 0
+        results: List[UserUpdateResult] = []
+
+        try:
+            # Perform bulk database update
+            await prisma_client.db.litellm_usertable.update_many(
+                where={}, data=non_default_values  # Update all users
+            )
+
+            # Create individual success results
+            for user in all_users_in_db:
+                results.append(
+                    UserUpdateResult(
+                        user_id=user.user_id,
+                        user_email=user.user_email,
+                        success=True,
+                        updated_user={"user_id": user.user_id, **non_default_values},
+                    )
+                )
+                successful_updates += 1
+
+            # Create single audit log entry for bulk operation
+            try:
+                asyncio.create_task(
+                    UserManagementEventHooks.create_internal_user_audit_log(
+                        user_id=user_api_key_dict.user_id or "",
+                        action="updated",
+                        litellm_changed_by=litellm_changed_by
+                        or user_api_key_dict.user_id,
+                        user_api_key_dict=user_api_key_dict,
+                        litellm_proxy_admin_name=litellm_proxy_admin_name,
+                        before_value=f"Updated {len(all_users_in_db)} users",
+                        after_value=json.dumps(non_default_values),
+                    )
+                )
+            except Exception as audit_error:
+                verbose_proxy_logger.warning(
+                    f"Failed to create bulk audit log: {audit_error}"
+                )
+
+        except Exception as e:
+            verbose_proxy_logger.exception(f"Failed to perform bulk update: {e}")
+            # Fall back to individual updates if bulk update fails
+            for user in all_users_in_db:
+                user_update_request = data.user_updates.model_copy()
+                user_update_request.user_id = user.user_id
+                users_to_update.append(user_update_request)  # type: ignore
+
+        if successful_updates > 0:
+            return BulkUpdateUserResponse(
+                results=results,
+                total_requested=len(all_users_in_db),
+                successful_updates=successful_updates,
+                failed_updates=failed_updates,
+            )
+
+    elif data.users:
+        users_to_update = data.users
+    else:
+        raise HTTPException(
+            status_code=400,
+            detail={
+                "error": "Must specify either 'users' for individual updates or 'all_users=True' with 'user_updates' for bulk updates"
+            },
+        )
+
+    if not users_to_update:
+        raise HTTPException(
+            status_code=400,
+            detail={"error": "No users found to update"},
+        )
+
+    # Limit batch size to prevent overwhelming the system
+    MAX_BATCH_SIZE = 500  # Increased limit for all-users operations
+    if len(users_to_update) > MAX_BATCH_SIZE:
+        raise HTTPException(
+            status_code=400,
+            detail={
+                "error": f"Maximum {MAX_BATCH_SIZE} users can be updated at once. Found {len(users_to_update)} users."
+            },
+        )
+
+    return await bulk_update_processed_users(
+        users_to_update=cast(List[UpdateUserRequest], users_to_update),
+        user_api_key_dict=user_api_key_dict,
+        litellm_changed_by=litellm_changed_by,
+    )
+
+
 async def get_user_key_counts(
     prisma_client,
     user_ids: Optional[List[str]] = None,
@@ -1226,6 +1546,9 @@ async def delete_user(
     Parameters:
     - user_ids: List[str] - The list of user id's to be deleted.
     """
+    from litellm.proxy.management_endpoints.team_endpoints import (
+        _cleanup_members_with_roles,
+    )
     from litellm.proxy.proxy_server import (
         create_audit_log_for_update,
         litellm_proxy_admin_name,
@@ -1274,6 +1597,34 @@ async def delete_user(
                     )
                 )
 
+        ## CLEANUP MEMBERS_WITH_ROLES
+        fetch_all_teams = await prisma_client.db.litellm_teamtable.find_many(
+            where={"team_id": {"in": user_row.teams}}
+        )
+        teams_to_update = []
+        for team in fetch_all_teams:
+            is_member_in_team, new_team_members = _cleanup_members_with_roles(
+                existing_team_row=LiteLLM_TeamTable(**team.model_dump()),
+                data=TeamMemberDeleteRequest(
+                    team_id=team.team_id,
+                    user_id=user_row.user_id,
+                    user_email=user_row.user_email,
+                ),
+            )
+            if is_member_in_team:
+                _db_new_team_members: List[dict] = [
+                    m.model_dump() for m in new_team_members
+                ]
+                team.members_with_roles = json.dumps(_db_new_team_members)
+                teams_to_update.append(team)
+
+        ## update teams
+
+        for team in teams_to_update:
+            await prisma_client.db.litellm_teamtable.update(
+                where={"team_id": team.team_id},
+                data={"members_with_roles": team.members_with_roles},
+            )
     # End of Audit logging
 
     ## DELETE ASSOCIATED KEYS
@@ -1291,6 +1642,11 @@ async def delete_user(
         where={"user_id": {"in": data.user_ids}}
     )
 
+    ## DELETE ASSOCIATED TEAM MEMBERSHIPS
+    await prisma_client.db.litellm_teammembership.delete_many(
+        where={"user_id": {"in": data.user_ids}}
+    )
+
     ## DELETE USERS
     deleted_users = await prisma_client.db.litellm_usertable.delete_many(
         where={"user_id": {"in": data.user_ids}}
