@@ -17,7 +17,7 @@ import uuid
 from typing import Dict, List, Literal, Optional, Tuple, Union, cast
 
 from fastapi import APIRouter, Depends, HTTPException, Request, status
-from pydantic import BaseModel
+from pydantic import BaseModel, ConfigDict, Field
 
 from litellm._logging import verbose_proxy_logger
 from litellm.constants import LITELLM_PROXY_ADMIN_NAME
@@ -44,6 +44,9 @@ from litellm.proxy.management_endpoints.team_endpoints import (
 )
 from litellm.proxy.management_helpers.audit_logs import create_object_audit_log
 from litellm.proxy.utils import PrismaClient
+from litellm.types.proxy.management_endpoints.model_management_endpoints import (
+    UpdateUsefulLinksRequest,
+)
 from litellm.types.router import (
     Deployment,
     DeploymentTypedDict,
@@ -55,6 +58,16 @@ from litellm.utils import get_utc_datetime
 router = APIRouter()
 
 
+class UpdatePublicModelGroupsRequest(BaseModel):
+    """Request model for updating public model groups"""
+
+    model_groups: List[str] = Field(
+        description="List of model group names to make public"
+    )
+
+    model_config = ConfigDict(extra="forbid")
+
+
 async def get_db_model(
     model_id: str, prisma_client: PrismaClient
 ) -> Optional[Deployment]:
@@ -945,6 +958,153 @@ async def update_model(
         )
 
 
+@router.post(
+    "/model_group/make_public",
+    description="Update which model groups are public",
+    tags=["model management"],
+    dependencies=[Depends(user_api_key_auth)],
+)
+async def update_public_model_groups(
+    request: UpdatePublicModelGroupsRequest,
+    user_api_key_dict: UserAPIKeyAuth = Depends(user_api_key_auth),
+):
+    """
+    Update which model groups are public.
+
+    This endpoint allows admins to specify which model groups should be publicly accessible.
+    Public model groups are visible via the /public/model_hub endpoint.
+
+    Args:
+        request: Request containing list of model group names to make public
+        user_api_key_dict: User authentication information
+
+    Returns:
+        Success message with updated public model groups
+
+    Raises:
+        ProxyException: For various error conditions including authentication errors
+    """
+    try:
+        # Update the public model groups
+        import litellm
+        from litellm.proxy.proxy_server import proxy_config
+
+        # Check if user has admin permissions
+        if user_api_key_dict.user_role != LitellmUserRoles.PROXY_ADMIN:
+            raise HTTPException(
+                status_code=403,
+                detail={
+                    "error": "Only proxy admins can update public model groups. Your role={}".format(
+                        user_api_key_dict.user_role
+                    )
+                },
+            )
+
+        litellm.public_model_groups = request.model_groups
+
+        # Load existing config
+        config = await proxy_config.get_config()
+
+        # Update config with new settings
+        if "litellm_settings" not in config:
+            config["litellm_settings"] = {}
+
+        config["litellm_settings"]["public_model_groups"] = request.model_groups
+
+        # Save the updated config
+        await proxy_config.save_config(new_config=config)
+
+        verbose_proxy_logger.info(
+            f"Updated public model groups to: {request.model_groups} by user: {user_api_key_dict.user_id}"
+        )
+
+        return {
+            "message": "Successfully updated public model groups",
+            "public_model_groups": request.model_groups,
+            "updated_by": user_api_key_dict.user_id,
+        }
+
+    except Exception as e:
+        verbose_proxy_logger.exception(f"Error updating public model groups: {str(e)}")
+
+        if isinstance(e, HTTPException):
+            raise e
+
+        raise ProxyException(
+            message=f"Error updating public model groups: {str(e)}",
+            type=ProxyErrorTypes.internal_server_error,
+            code=status.HTTP_500_INTERNAL_SERVER_ERROR,
+            param=None,
+        )
+
+
+@router.post(
+    "/model_hub/update_useful_links",
+    description="Update useful links",
+    tags=["model management"],
+    dependencies=[Depends(user_api_key_auth)],
+)
+async def update_useful_links(
+    request: UpdateUsefulLinksRequest,
+    user_api_key_dict: UserAPIKeyAuth = Depends(user_api_key_auth),
+):
+    """
+    Update useful links.
+    """
+    try:
+        # Update the public model groups
+        import litellm
+        from litellm.proxy.proxy_server import proxy_config
+
+        # Check if user has admin permissions
+        if user_api_key_dict.user_role != LitellmUserRoles.PROXY_ADMIN:
+            raise HTTPException(
+                status_code=403,
+                detail={
+                    "error": "Only proxy admins can update public model groups. Your role={}".format(
+                        user_api_key_dict.user_role
+                    )
+                },
+            )
+
+        litellm.public_model_groups_links = request.useful_links
+
+        # Load existing config
+        config = await proxy_config.get_config()
+
+        # Update config with new settings
+        if "litellm_settings" not in config:
+            config["litellm_settings"] = {}
+
+        config["litellm_settings"]["public_model_groups_links"] = request.useful_links
+
+        # Save the updated config
+        await proxy_config.save_config(new_config=config)
+
+        verbose_proxy_logger.info(
+            f"Updated useful links to: {request.useful_links} by user: {user_api_key_dict.user_id}"
+        )
+
+        return {
+            "message": "Successfully updated useful links",
+            "useful_links": request.useful_links,
+            "updated_by": user_api_key_dict.user_id,
+        }
+
+    except Exception as e:
+        verbose_proxy_logger.exception(f"Error updating public model groups: {str(e)}")
+
+        if isinstance(e, HTTPException):
+            raise e
+
+        raise ProxyException(
+            message=f"Error updating public model groups: {str(e)}",
+            type=ProxyErrorTypes.internal_server_error,
+            code=status.HTTP_500_INTERNAL_SERVER_ERROR,
+            param=None,
+        )
+
+
 def _deduplicate_litellm_router_models(models: List[Dict]) -> List[Dict]:
     """
     Deduplicate models based on their model_info.id field.
@@ -986,6 +1146,7 @@ async def clear_cache():
 
     try:
         llm_router.model_list.clear()
+        llm_router.auto_routers.clear()
 
         await proxy_config.add_deployment(
             prisma_client=prisma_client, proxy_logging_obj=proxy_logging_obj
